Learn R Programming

FixSeqMTP (version 0.1.2)

FSFWER.arbidept.cv: Critical Values for Fixed Sequence FWER Controlling Procedures under Arbitrary Dependence

Description

Given a set of pre-ordered p-values and accuracy for the result, return the corresponding critical values using one of three generalized fixed sequence FWER controlling procedures. The function also provides an option to make decisions given a pre-specified significant level $\alpha$.

Usage

FSFWER.arbidept.cv(p, alpha=0.05, beta=0.5, tol = 1e-6, method = c("reject","accept","both"), make.decision = TRUE)

Arguments

p
numeric vector of p-values (possibly with NAs). Any other R is coerced by as.numeric. Same as in p.adjust.
alpha
significant level used to calculate the critical values to make decisions, the default value is 0.05.
beta
pre-specified constant satisfying $0 \le \beta <1$, only="" for="" method="accept". The default value is 0.5.
tol
desired accuracy. The default value is 1e-6 .
method
critical value calculation method. See details.
make.decision
logical; if TRUE (default), then the output include the decision rules compared adjusted p-values with significant level $alpha$

Value

A numeric vector of the critical values (of the same length as p) if make.decision = FALSE, or a data frame including original p-values, critical values and decision rules if make.decision = TRUE.

Details

The critical value calculation methods for Fixed Sequence multiple testing include Procedure A1 only using numbers of rejections ("reject"), Procedure A2 only using numbers of acceptances ("accept") and Procedure A3 using both numbers of rejections and numbers of acceptances ("both"). The three methods strongly control FWER under arbitrary dependence. The constant beta needs to be specified for the Procedure A2 ("accept"), while one can ignore this argument when using other methods.

References

Qiu, Z., Guo, W., & Lynch, G. (2015). On generalized fixed sequence procedures for controlling the FWER. Statistics in medicine, 34(30), 3968-3983.

See Also

FSFDR.arbidept.cv and FSFDR.indept.cv for fixed sequence FDR controlling procedures.

Examples

Run this code
  ## Clinical trial example in Qiu et al. (2015)
Pval <- c(0.0008, 0.0135, 0.0197, 0.7237, 0.0003, 0.2779, 0.0054, 0.8473)
FSFWER.arbidept.cv(p=Pval, alpha=0.05, method = "reject")
FSFWER.arbidept.cv(p=Pval, alpha=0.05, beta=0.1, method = "accept")
FSFWER.arbidept.cv(p=Pval, alpha=0.05, beta=0.5, method = "accept")
FSFWER.arbidept.cv(p=Pval, alpha=0.05, beta=0.9, method = "accept")
FSFWER.arbidept.cv(p=Pval, alpha=0.05, method = "both")

Run the code above in your browser using DataLab